import { Switch, Route, useLocation } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import UsercentricsConsent from "./components/UsercentricsConsent";
import React, { Suspense, lazy, useEffect } from "react";
import { CLIENT_ROUTES } from "./lib/runtimeConfig";
import { LanguageProvider } from "./context/LanguageContext";

// Eagerly loaded components for critical pages
import NotFound from "@/pages/NotFound";
import Home from "@/pages/Home";

// Google Analytics Tag component
import GoogleAnalytics from "./components/GoogleAnalytics";

// For admin routes, we're now importing these directly to ensure they're included in the build
import AdminLoginPage from "@/pages/AdminLogin";
import AdminDashboardPage from "@/pages/AdminDashboard";

// Lazy loaded components for non-critical pages
const Terms = lazy(() => import("@/pages/Terms"));
const Dmca = lazy(() => import("@/pages/Dmca"));
const Blog = lazy(() => import("@/pages/Blog"));
const About = lazy(() => import("@/pages/About"));
const YouTube = lazy(() => import("@/pages/YouTube"));
const TikTok = lazy(() => import("@/pages/TikTok"));
const Instagram = lazy(() => import("@/pages/Instagram"));
const Facebook = lazy(() => import("@/pages/Facebook"));
const Twitter = lazy(() => import("@/pages/Twitter"));
const Snapchat = lazy(() => import("@/pages/Snapchat"));
const Trending = lazy(() => import("@/pages/Trending"));
const GuideContent = lazy(() => import("@/pages/GuideContent"));
const VideoTrimmer = lazy(() => import("@/pages/VideoTrimmer"));

// Admin components can be lazy loaded but we need to make sure they're reachable
const AdminLogin = AdminLoginPage;
const AdminDashboard = AdminDashboardPage;

// Loading fallback component
const LoadingFallback = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="bg-white p-6 rounded-lg shadow-md max-w-md w-full">
      <div className="animate-pulse space-y-4">
        <div className="h-8 bg-gray-200 rounded w-3/4 mx-auto"></div>
        <div className="h-4 bg-gray-200 rounded w-full"></div>
        <div className="h-4 bg-gray-200 rounded w-5/6"></div>
        <div className="h-4 bg-gray-200 rounded w-4/6"></div>
        <div className="h-12 bg-gray-200 rounded w-2/3 mx-auto"></div>
      </div>
    </div>
  </div>
);

function Router() {
  return (
    <Switch>
      {/* Critical paths loaded eagerly */}
      <Route path={CLIENT_ROUTES.HOME} component={Home} />
      <Route path="/not-found" component={NotFound} />
      
      {/* Non-critical paths loaded lazily */}
      <Route path="/terms">
        <Suspense fallback={<LoadingFallback />}>
          <Terms />
        </Suspense>
      </Route>
      <Route path="/dmca">
        <Suspense fallback={<LoadingFallback />}>
          <Dmca />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.TRENDING}>
        <Suspense fallback={<LoadingFallback />}>
          <Trending />
        </Suspense>
      </Route>
      <Route path="/trending-videos">
        <Suspense fallback={<LoadingFallback />}>
          <Trending />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.YOUTUBE}>
        <Suspense fallback={<LoadingFallback />}>
          <YouTube />
        </Suspense>
      </Route>
      <Route path="/youtube-downloader-no-limits">
        <Suspense fallback={<LoadingFallback />}>
          <YouTube />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.TIKTOK}>
        <Suspense fallback={<LoadingFallback />}>
          <TikTok />
        </Suspense>
      </Route>
      <Route path="/tiktok-downloader-no-watermark">
        <Suspense fallback={<LoadingFallback />}>
          <TikTok />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.INSTAGRAM}>
        <Suspense fallback={<LoadingFallback />}>
          <Instagram />
        </Suspense>
      </Route>
      <Route path="/instagram-video-downloader">
        <Suspense fallback={<LoadingFallback />}>
          <Instagram />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.FACEBOOK}>
        <Suspense fallback={<LoadingFallback />}>
          <Facebook />
        </Suspense>
      </Route>
      <Route path="/facebook-video-downloader">
        <Suspense fallback={<LoadingFallback />}>
          <Facebook />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.TWITTER}>
        <Suspense fallback={<LoadingFallback />}>
          <Twitter />
        </Suspense>
      </Route>
      <Route path="/twitter-video-downloader">
        <Suspense fallback={<LoadingFallback />}>
          <Twitter />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.SNAPCHAT}>
        <Suspense fallback={<LoadingFallback />}>
          <Snapchat />
        </Suspense>
      </Route>
      <Route path="/snapchat-video-downloader">
        <Suspense fallback={<LoadingFallback />}>
          <Snapchat />
        </Suspense>
      </Route>
      <Route path="/guide">
        <Suspense fallback={<LoadingFallback />}>
          <GuideContent />
        </Suspense>
      </Route>
      <Route path="/how-to-download-videos">
        <Suspense fallback={<LoadingFallback />}>
          <GuideContent />
        </Suspense>
      </Route>
      <Route path="/blog">
        <Suspense fallback={<LoadingFallback />}>
          <Blog />
        </Suspense>
      </Route>
      <Route path="/about">
        <Suspense fallback={<LoadingFallback />}>
          <About />
        </Suspense>
      </Route>
      <Route path="/about-us">
        <Suspense fallback={<LoadingFallback />}>
          <About />
        </Suspense>
      </Route>
      <Route path="/video-trimmer">
        <Suspense fallback={<LoadingFallback />}>
          <VideoTrimmer />
        </Suspense>
      </Route>
      <Route path="/trim">
        <Suspense fallback={<LoadingFallback />}>
          <VideoTrimmer />
        </Suspense>
      </Route>
      
      {/* Admin Routes */}
      <Route path={CLIENT_ROUTES.ADMIN_LOGIN}>
        <Suspense fallback={<LoadingFallback />}>
          <AdminLogin />
        </Suspense>
      </Route>
      <Route path={CLIENT_ROUTES.ADMIN_DASHBOARD}>
        <Suspense fallback={<LoadingFallback />}>
          <AdminDashboard />
        </Suspense>
      </Route>
      <Route path="/admin">
        <Suspense fallback={<LoadingFallback />}>
          <AdminLogin />
        </Suspense>
      </Route>
      
      {/* 404 Route */}
      <Route>
        <NotFound />
      </Route>
    </Switch>
  );
}

// Route tracking for analytics
function RouteTracker() {
  const [location, setLocation] = useLocation();
  
  useEffect(() => {
    // Track page view when location changes
    if (window.gtag) {
      window.gtag('config', 'G-CQ0L9XGWE0', {
        page_path: location,
      });
    }
    
    // Store the current path for persistence across page refreshes
    // This is especially important for admin routes
    if (location.startsWith('/admin')) {
      localStorage.setItem('lastVisitedRoute', location);
    }
  }, [location]);
  
  // Handle admin redirect path from localStorage (for HTML fallbacks)
  useEffect(() => {
    // First check for the direct redirect parameter
    const savedPath = localStorage.getItem('adminRedirectPath');
    if (savedPath) {
      // Clear it immediately to prevent infinite loop
      localStorage.removeItem('adminRedirectPath');
      
      // Only redirect if we're on the home page and there was a saved admin path
      if (location === '/' && savedPath.startsWith('/admin')) {
        console.log('Redirecting to saved admin path:', savedPath);
        // Small delay to ensure the app has fully loaded
        setTimeout(() => {
          setLocation(savedPath);
        }, 100);
        return;
      }
    }
    
    // Also check for general route restoration on initial page load
    // Check if we have a special flag to prevent redirection
    const preventAdminRedirect = localStorage.getItem('preventAdminRedirect');
    
    if (location === '/' && !preventAdminRedirect) {
      const lastVisitedRoute = localStorage.getItem('lastVisitedRoute');
      if (lastVisitedRoute && lastVisitedRoute.startsWith('/admin')) {
        console.log('Restoring last admin route:', lastVisitedRoute);
        setTimeout(() => {
          setLocation(lastVisitedRoute);
        }, 100);
      }
    }
  }, [location, setLocation]);
  
  return null;
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      {/* Google Analytics */}
      <GoogleAnalytics />
      
      {/* Usercentrics Consent Management Platform */}
      <UsercentricsConsent />
      
      {/* Language Provider */}
      <LanguageProvider>
        {/* Route tracking */}
        <RouteTracker />
        
        {/* Main router */}
        <Router />
        
        {/* Toast notifications */}
        <Toaster />
      </LanguageProvider>
    </QueryClientProvider>
  );
}

export default App;